import json
from django.shortcuts import render
from django.views.generic import View
from dcim.models import (
    Device, 
    Cable, 
    Interface,
)


#
# NetworkDiagram views
#
class NetworkDiagramView(View):
    def get(self, request):
        # 全ての Device を nodes に追加します。
        nodes = []
        device_list = Device.objects.all()
        for d in device_list:
            location = ""
            if d.location != None:
                location = d.location.name

            nodes.append({ 
                "name": d.name, 
                "group": location, 
                "meta": {
                    "description": d.description,
                }, 
                "icon": "/static/netbox_network_diagram/img/switch.png" 
            })
        
        # Cable の接続情報を元に Device 間の接続を links に追加します。
        links = []
        cable_list = Cable.objects.all()
        for c in cable_list:
            if len(c.a_terminations) != 1 and len(c.b_terminations) != 1:
                continue

            a_termination = c.a_terminations[0]
            b_termination = c.b_terminations[0]

            if not isinstance(a_termination, Interface) or not isinstance(b_termination, Interface):
                continue

            if_source = a_termination.name
            if_target = b_termination.name

            if a_termination.device == None or b_termination.device == None:
                continue

            source = a_termination.device.name
            target = b_termination.device.name

            links.append({
                "source": source,
                "target": target,
                "meta": {
                    "interface": {
                        "source": if_source,
                        "target": if_target,
                    },
                    "description": "",
                }
            })
        
        # inet-henge で描画できる形式にします。
        data = { "nodes": nodes, "links": links}

        return render(
            request,
            "netbox_network_diagram/index.html",
            {"data": json.dumps(data)},
        )



from extras.plugins import PluginConfig


class NetBoxNetworkDiagramConfig(PluginConfig):
    name = 'netbox_network_diagram'
    verbose_name = ' NetBox Network Diagram'
    description = 'A plugin to render network diagram in NetBox'
    version = '0.1'
    base_url = 'network-diagram'
    min_version = '3.4.0'


config = NetBoxNetworkDiagramConfig



from extras.plugins import PluginMenu, PluginMenuItem

menu = PluginMenu(
    label='Network Diagram',
    icon_class='mdi mdi-sitemap',
    groups=(
        ('Network Diagram', (
            PluginMenuItem(
                link='plugins:netbox_network_diagram:network_diagram',
                link_text='Network Diagram',
            ),
        ),),
    ),
)


#!/usr/bin/env python

from setuptools import find_packages, setup

with open('README.md') as readme_file:
    long_description = readme_file.read()

setup(
    name='netbox-network-diagram',
    version='0.1.0',
    description='A plugin to render network diagram in NetBox.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/entooone/netbox-network-diagram",
    author="entooone",
    author_email="entooone@gmail.com",
    license='MIT',
    install_requires=[],
    keywords=["netbox-plugin"],
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
    ],
    project_urls={
        "Source": "https://github.com/entooone/netbox-network-diagram",
        "Tracker": "https://github.com/entooone/netbox-network-diagram/issues",
    },
    include_package_data=True,
    zip_safe=False,
)
